@@ -12,9 +12,14 @@ ProviderWindow::ProviderWindow(QWidget *parent, WrPlugin *plugin) :
     QMainWindow(parent),
     ui(new Ui::ProviderWindow)
 {
+    qDebug() << "ProviderWindow::ProviderWindow()";
     ui->setupUi(this);
     ui->menuMenu->setTitle("");
+    model = new QStandardItemModel(this);
     ui->tblProviders->setModel(model);
+    ui->tblProviders->setProperty("FingerScrollable", true);
+    ui->tblProviders->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+    qDebug() << "Adding providers";
     this->plugin = plugin;
     int row = 0;
     for(int i = 0; i<plugin->searchProviders().count(); i++) {
@@ -36,6 +41,7 @@ ProviderWindow::ProviderWindow(QWidget *parent, WrPlugin *plugin) :
         model->setItem(row, 2, removeItem);
         row++;
     }
+    qDebug() << "Providers added";
 }
 
 ProviderWindow::~ProviderWindow()
@@ -57,10 +63,12 @@ void ProviderWindow::changeEvent(QEvent *e)
 
 void ProviderWindow::on_tblProviders_clicked(QModelIndex index)
 {
+    qDebug() << "Clicked on table";
     QStandardItem *item = model->itemFromIndex(index);
     QVariantHash itemData = item->data().toHash();
     QString baseUri = itemData.value("baseUri").toString();
     int providerId = itemData.value("providerId").toInt();
+    qDebug() << "Checking column";
     if(item->column() == 0) {
         QString uri = baseUri.replace("%s", QUrl::toPercentEncoding(plugin->barcodeText)); // replace %s with barcodeText
         QDBusInterface *interface = new QDBusInterface("com.nokia.osso_browser","/com/nokia/osso_browser/request","com.nokia.osso_browser");
@@ -82,6 +90,7 @@ void ProviderWindow::on_tblProviders_clicked(QModelIndex index)
             plugin->removeSearchProvider(plugin->searchProviders().at(providerId));
         }
     }
+    qDebug() << "done click";
     this->close();
 }
 
