@@ -6,6 +6,8 @@
 #include <mbarcode-qt/plugininterfaces.h>
 #include <mbarcode-qt/sinkplugin.h>
 
+class WrPlugin;
+
 class WrSink : public QObject, public SinkPlugin
 {
     Q_OBJECT
@@ -16,6 +18,7 @@ public:
     QString getText();
     bool isReady();
     void clickAction(QWidget *parentWindow);
+    void setPlugin(WrPlugin* plugin);
     // other
     //QString url;
 private slots:
@@ -25,25 +28,7 @@ private:
     QString buttonText;
     QString barcodeText;
     int type;
-
-    enum barcodeType {
-        Unknown=0,
-        Email,
-        URL,
-        SMS,
-        MMS,
-        PhoneNumber,
-        vCard,
-        BizCard,
-        iMode,
-        Geo,
-        YouTube,
-        Install,
-        Ovi
-    };
-    void openGeneric(QString uri);
-    void addVCard(QString user_data);
-    void openInstallFile(QString data);
+    WrPlugin *plugin;
     // other
 };
 
